Module compute_kernel

Module compute_kernel 

Structs

ComputeKernel
Represents a compiled compute, ready for execution.
ComputeKernelBuilder
A builder for creating a ComputeKernel.
KernelBinding
Helper struct to define a binding layout for a kernel.

Enums

BindingType
Describes the type of data bound to a kernel.

Traits

Dispatch
Trait for defining compute workgroup dimensions.
KernelArgument
A trait for types that can be passed as arguments to a compute kernel.