Structs
- Compute
Kernel - Represents a compiled compute, ready for execution.
- Compute
Kernel Builder - A builder for creating a
ComputeKernel. - Kernel
Binding - Helper struct to define a binding layout for a kernel.
Enums
- Binding
Type - Describes the type of data bound to a kernel.
Traits
- Dispatch
- Trait for defining compute workgroup dimensions.
- Kernel
Argument - A trait for types that can be passed as arguments to a compute kernel.